package Locale::VersionedMessages::Sets::lm_gui;
####################################################
#        *** WARNING WARNING WARNING ***
#
# This file was generated, and is intended to be
# maintained automatically using the Locale::VersionedMessages
# tools.
#
# Any changes to this file may be lost the next
# time these commands are run.
####################################################

use strict;
use warnings;

our($DefaultLocale,@AllLocale,%Messages);

$DefaultLocale = 'en_US';
@AllLocale     = (qw(en_US fr_FR));

%Messages = (
   'button: add locale' => {
      'desc'  => q{Add Locale button label},
   },
   'button: add message' => {
      'desc'  => q{Add Message button label},
   },
   'button: browse' => {
      'desc'  => q{Browse button label},
   },
   'button: exit' => {
      'desc'  => q{Exit button label},
   },
   'button: sel locale' => {
      'desc'  => q{Select Locale button label},
   },
   'button: submit' => {
      'desc'  => q{Submit button label},
   },
   'create_set: instructions' => {
      'desc'  => q{Instructions on the create_set window.},
   },
   'create_set: loc err' => {
      'desc'  => q{create_set loc error message},
   },
   'create_set: locale' => {
      'desc'  => q{Label for <Default Locale> box.},
   },
   'create_set: window title' => {
      'desc'  => q{Window title for create_set window.},
      'vals'  => ['COM'],
   },
   'error' => {
      'desc'  => q{Error label},
   },
   'manage_set: curr' => {
      'desc'  => q{Label for <Current Locale> box.},
   },
   'manage_set: def' => {
      'desc'  => q{Label for <Default Locale> box.},
   },
   'manage_set: def mess instructions' => {
      'desc'  => q{Instructions for editing a message in the default locale.},
   },
   'manage_set: desc' => {
      'desc'  => q{Label for <Message Description> box.},
   },
   'manage_set: edit mess instructions' => {
      'desc'  => q{Instructions for editing a message in a locale.},
   },
   'manage_set: leave version unmodified' => {
      'desc'  => q{Label for <Leave Version Unmodified> box.},
   },
   'manage_set: mark ood' => {
      'desc'  => q{Label for <Mark Out-Of-Date> box.},
   },
   'manage_set: msgid' => {
      'desc'  => q{Label for <Message ID> box.},
   },
   'manage_set: msgid list' => {
      'desc'  => q{Label for msgID listbox.},
      'vals'  => ['SET'],
   },
   'manage_set: new mess def err' => {
      'desc'  => q{Creating a new message missing default text error.},
   },
   'manage_set: new mess instructions' => {
      'desc'  => q{Instructions for creating a new message.},
   },
   'manage_set: new mess msgid err' => {
      'desc'  => q{Creating a duplicate message ID error.},
   },
   'manage_set: subst' => {
      'desc'  => q{Label for <Substitution Values> box.},
   },
   'manage_set: window title' => {
      'desc'  => q{Window title for manage_set window.},
      'vals'  => ['COM'],
   },
   'select_operation: desc err' => {
      'desc'  => q{select_operation desc error message},
   },
   'select_operation: description' => {
      'desc'  => q{Label for <Message Set Description> box.},
   },
   'select_operation: directory' => {
      'desc'  => q{Label for <Select Directory> box.},
   },
   'select_operation: err' => {
      'desc'  => q{select_operation error message},
   },
   'select_operation: instructions_1' => {
      'desc'  => q{Instructions on the select_operation window.},
   },
   'select_operation: instructions_2' => {
      'desc'  => q{Instructions on the select_operation window.},
   },
   'select_operation: set' => {
      'desc'  => q{Label for <Message Set> box.},
   },
   'select_operation: set err' => {
      'desc'  => q{select_operation set error message},
   },
   'select_operation: window title' => {
      'desc'  => q{Window title for select_operation window.},
      'vals'  => ['COM'],
   },
);

1;

=pod

=head1 NAME

Locale::VersionedMessages::Sets::lm_gui -- Description of the lm_gui message set

=head1 DESCRIPTION

This module is not intended for public use. It is used internally by
Locale::VersionedMessages to store the description of a set of messages that
will be localized for some application.

=cut
