package Locale::VersionedMessages::Sets::Test2::fr_FR;
####################################################
#        *** WARNING WARNING WARNING ***
#
# This file was generated, and is intended to be
# maintained automatically using the lm_admin command.
# Any changes to this file may be lost the next
# time the command is run.
####################################################

use strict;
use warnings;

our(%Messages);

%Messages = (
   'Subst_1a' => {
      'vers'  => 2,
      'text'  => 'Substitution message 1a with value [aaa] in French.
',
   },
   'Subst_3a' => {
      'vers'  => 2,
      'text'  => 'Substitution message 3a with [n:quant [_n==1] [one value] [_n==2] [two values] [_n values]] in French.
',
   },
);

1;
