package Locale::VersionedMessages::Sets::Test1::de_DE;
####################################################
#        *** WARNING WARNING WARNING ***
#
# This file was generated, and is intended to be
# maintained automatically using the lm_admin command.
# Any changes to this file may be lost the next
# time the command is run.
####################################################

use strict;
use warnings;

our(%Messages);

%Messages = (
   'Message_1' => {
      'vers'  => 2,
      'text'  => 'Message #1 in German.
',
   },
   'Message_2' => {
      'vers'  => 2,
      'text'  => 'Message #2 in German.
',
   },
   'Message_3' => {
      'vers'  => 2,
      'text'  => 'Message #3 in German.
',
   },
);

1;
